/*
 * lilJudd
 * Copyright (C) 2023 limited_dev
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package de.limited_dev.lilJudd

import com.kotlindiscord.kord.extensions.ExtensibleBot
import de.limited_dev.botendo.build.BuildConstants
import de.limited_dev.lilJudd.data.CredentialManager
import de.limited_dev.lilJudd.data.DB
import de.limited_dev.lilJudd.extensions.VersionExtension
import de.limited_dev.lilJudd.util.Logger
import dev.kord.common.entity.PresenceStatus
import kotlin.system.exitProcess

object Bot {
    //The kord object gets set at app launch
    private lateinit var bot: ExtensibleBot
    suspend fun start() {
        Logger.out("Starting Bot...")

        //Load config
        CredentialManager.load()

        //Don't run the bot when there is no bot token in config
        if (CredentialManager.token == "empty") {
            Logger.out("The config does not contain a bot token.")
            exitProcess(3)
        }

        //Check if the credentials for the Database are existent
        if (CredentialManager.dbDomain == "empty" || CredentialManager.dbName == "empty" || CredentialManager.dbUser == "empty" || CredentialManager.dbPassword == "empty") {
            Logger.out("The config does not contain the whole Database credentials.")
            exitProcess(3)
        }

        //Connect to the Database
        DB.connect(
            CredentialManager.dbDomain,
            CredentialManager.dbName,
            CredentialManager.dbUser,
            CredentialManager.dbPassword
        )

        //Add Bot token to kord
        bot = ExtensibleBot(CredentialManager.token) {
            applicationCommands {
                enabled = true
            }

            extensions {
                add(::VersionExtension)
            }

            this.presence {
                this.status = PresenceStatus.DoNotDisturb
                this.streaming("v" + BuildConstants.version, "https://www.twitch.tv/deutschesplbundesliga")
            }
        }

        //Start the bot
        bot.start()
    }
}
